==> ecore_1.0.0.orig.tar.gz: ecore-1.0.0/src/lib/ecore_fb/ecore_fb_keytable.h <==
/* this table was taken from ecore_fb, is the default en layout */
         "0x00",          "0x00",          "0x00", /**/"",    "",    "",/***/
       "Escape",        "Escape",        "Escape", /**/"",    "",    "",/***/
            "1",        "exclam",             "1", /**/"1",   "!",   "1",/***/
            "2",            "at",             "2", /**/"2",   "@",   "2",/***/
            "3",    "numbersign",             "3", /**/"3",   "#",   "3",/***/
            "4",        "dollar",             "4", /**/"4",   "$",   "4",/***/
            "5",       "percent",             "5", /**/"5",   "%",   "5",/***/
            "6",  "asciicircumm",             "6", /**/"6",   "^",   "6",/***/
            "7",     "ampersand",             "7", /**/"7",   "&",   "7",/***/
            "8",       "asterik",             "8", /**/"8",   "*",   "8",/***/
            "9",     "parenleft",             "9", /**/"9",   "(",   "9",/***/
            "0",    "parenright",             "0", /**/"0",   ")",   "0",/***/
        "minus",    "underscore",         "minus", /**/"-",   "_",   "-",/***/
        "equal",          "plus",         "equal", /**/"=",   "+",   "=",/***/
    "BackSpace",     "BackSpace",     "BackSpace", /**/"\010","\010","\010",/***/
          "Tab",  "ISO_Left_Tab",           "Tab", /**/"\011","",    "\011",/***/
            "q",             "Q",             "Q", /**/"q",   "Q",   "Q",/***/
            "w",             "W",             "W", /**/"w",   "W",   "W",/***/
            "e",             "E",             "E", /**/"e",   "E",   "E",/***/
            "r",             "R",             "R", /**/"r",   "R",   "R",/***/
            "t",             "T",             "T", /**/"t",   "T",   "T",/***/
            "y",             "Y",             "Y", /**/"y",   "Y",   "Y",/***/
            "u",             "U",             "U", /**/"u",   "U",   "U",/***/
            "i",             "I",             "I", /**/"i",   "I",   "I",/***/
            "o",             "O",             "O", /**/"o",   "O",   "O",/***/
            "p",             "P",             "P", /**/"p",   "P",   "P",/***/
  "bracketleft",     "braceleft",   "bracketleft", /**/"[",   "{",   "[",/***/
 "bracketright",    "braceright",  "bracketright", /**/"]",   "}",   "]",/***/
       "Return",        "Return",        "Return", /**/"\015","\015","\015",/***/
    "Control_L",     "Control_L",     "Control_L", /**/"",    "",    "",/***/
            "a",             "A",             "A", /**/"a",   "A",   "A",/***/
            "s",             "S",             "S", /**/"s",   "S",   "S",/***/
            "d",             "D",             "D", /**/"d",   "D",   "D",/***/
            "f",             "F",             "F", /**/"f",   "F",   "F",/***/
            "g",             "G",             "G", /**/"g",   "G",   "G",/***/
            "h",             "h",             "H", /**/"h",   "H",   "H",/***/
            "j",             "J",             "J", /**/"j",   "J",   "J",/***/
            "k",             "K",             "K", /**/"k",   "K",   "K",/***/
            "l",             "L",             "L", /**/"l",   "L",   "L",/***/
    "semicolon",         "colon",     "semicolon", /**/";",   ":",   ";",/***/
   "apostrophe",      "quotedbl",    "apostrophe", /**/"'",   "\"",  "'",/***/
        "grave",    "asciitilde",         "grave", /**/"`",   "~",   "`",/***/
      "Shift_L",       "Shift_L",       "Shift_L", /**/"",    "",    "",/***/
    "backslash",           "bar",     "backslash", /**/"\\",  "|",   "\\",/***/
            "z",             "Z",             "Z", /**/"z",   "Z",   "Z",/***/
            "x",             "X",             "X", /**/"x",   "X",   "X",/***/
            "c",             "C",             "C", /**/"c",   "C",   "C",/***/
            "v",             "V",             "V", /**/"v",   "V",   "V",/***/
            "b",             "B",             "B", /**/"b",   "B",   "B",/***/
            "n",             "N",             "N", /**/"n",   "N",   "N",/***/
            "m",             "M",             "M", /**/"m",   "M",   "M",/***/
        "comma",          "less",         "comma", /**/",",   "<",   ",",/***/
       "period",       "greater",        "period", /**/".",   ">",   ".",/***/
        "slash",      "question",         "slash", /**/"/",   "?",   "/",/***/
      "Shift_R",       "Shift_R",       "Shift_R", /**/"",    "",    "",/***/
  "KP_Multiply",   "KP_Multiply",   "KP_Multiply", /**/"",    "*",   "",/***/
        "Alt_L",         "Alt_L",         "Alt_L", /**/"",    "",    "",/***/
        "space",         "space",         "space", /**/" ",   " ",   " ",/***/
    "Caps_Lock",     "Caps_Lock",     "Caps_Lock", /**/"",    "",    "",/***/
           "F1",            "F1",            "F1", /**/"",    "",    "",/***/
           "F2",            "F2",            "F2", /**/"",    "",    "",/***/
           "F3",            "F3",            "F3", /**/"",    "",    "",/***/
           "F4",            "F4",            "F4", /**/"",    "",    "",/***/
           "F5",            "F5",            "F5", /**/"",    "",    "",/***/
           "F6",            "F6",            "F6", /**/"",    "",    "",/***/
           "F7",            "F7",            "F7", /**/"",    "",    "",/***/
           "F8",            "F8",            "F8", /**/"",    "",    "",/***/
           "F9",            "F9",            "F9", /**/"",    "",    "",/***/
          "F10",           "F10",           "F10", /**/"",    "",    "",/***/
     "Num_Lock",      "Num_Lock",      "Num_Lock", /**/"",    "",    "",/***/
  "Scroll_Lock",   "Scroll_Lock",   "Scroll_Lock", /**/"",    "",    "",/***/
      "KP_Home",          "KP_7",       "KP_Home", /**/"",    "7",   "",/***/
        "KP_Up",          "KP_8",         "KP_Up", /**/"",    "8",   "",/***/
     "KP_Prior",          "KP_9",      "KP_Prior", /**/"",    "9",   "",/***/
  "KP_Subtract",   "KP_Subtract",   "KP_Subtract", /**/"",    "",    "",/***/
      "KP_Left",          "KP_4",       "KP_Left", /**/"",    "4",   "",/***/
     "KP_Begin",          "KP_5",      "KP_Begin", /**/"",    "5",   "",/***/
     "KP_Right",          "KP_6",      "KP_Right", /**/"",    "6",   "",/***/
       "KP_Add",        "KP_Add",        "KP_Add", /**/"",    "",    "",/***/
       "KP_End",          "KP_1",        "KP_End", /**/"",    "1",   "",/***/
      "KP_Down",          "KP_2",       "KP_Down", /**/"",    "2",   "",/***/
      "KP_Next",          "KP_3",       "KP_Next", /**/"",    "3",   "",/***/
    "KP_Insert",          "KP_0",     "KP_Insert", /**/"",    "0",   "",/***/
    "KP_Delete",    "KP_Decimal",     "KP_Delete", /**/"",    ".",   "",/***/
         "0x54",          "0x54",          "0x54", /**/"",    "",    "",/***/
         "0x55",          "0x55",          "0x55", /**/"",    "",    "",/***/
         "0x56",          "0x56",          "0x56", /**/"",    "",    "",/***/
          "F11",           "F11",           "F11", /**/"",    "",    "",/***/
          "F12",           "F12",           "F12", /**/"",    "",    "",/***/
         "0x59",          "0x59",          "0x59", /**/"",    "",    "",/***/
         "0x5a",          "0x5a",          "0x5a", /**/"",    "",    "",/***/
         "0x5b",          "0x5b",          "0x5b", /**/"",    "",    "",/***/
         "0x5c",          "0x5c",          "0x5c", /**/"",    "",    "",/***/
         "0x5d",          "0x5d",          "0x5d", /**/"",    "",    "",/***/
         "0x5e",          "0x5e",          "0x5e", /**/"",    "",    "",/***/
         "0x5f",          "0x5f",          "0x5f", /**/"",    "",    "",/***/
     "KP_Enter",      "KP_Enter",      "KP_Enter", /**/"",    "",    "",/***/
    "Control_R",     "Control_R",     "Control_R", /**/"",    "",    "",/***/
    "KP_Divide",     "KP_Divide",     "KP_Divide", /**/"",    "",    "",/***/
        "Print",         "Print",         "Print", /**/"",    "",    "",/***/
        "Alt_R",         "Alt_R",         "Alt_R", /**/"",    "",    "",/***/
         "0x65",          "0x65",          "0x65", /**/"",    "",    "",/***/
         "Home",          "Home",          "Home", /**/"",    "",    "",/***/
           "Up",            "Up",            "Up", /**/"",    "",    "",/***/
        "Prior",         "Prior",         "Prior", /**/"",    "",    "",/***/
         "Left",          "Left",          "Left", /**/"",    "",    "",/***/
        "Right",         "Right",         "Right", /**/"",    "",    "",/***/
          "End",           "End",           "End", /**/"",    "",    "",/***/
         "Down",          "Down",          "Down", /**/"",    "",    "",/***/
         "Next",          "Next",          "Next", /**/"",    "",    "",/***/
       "Insert",        "Insert",        "Insert", /**/"",    "",    "",/***/
       "Delete",        "Delete",        "Delete", /**/"\177","\177","\177",/***/
         "0x70",          "0x70",          "0x70", /**/"",    "",    "",/***/
         "0x71",          "0x71",          "0x71", /**/"",    "",    "",/***/
         "0x72",          "0x72",          "0x72", /**/"",    "",    "",/***/
         "0x73",          "0x73",          "0x73", /**/"",    "",    "",/***/
         "0x74",          "0x74",          "0x74", /**/"",    "",    "",/***/
         "0x75",          "0x75",          "0x75", /**/"",    "",    "",/***/
         "0x76",          "0x76",          "0x76", /**/"",    "",    "",/***/
        "Pause",         "Pause",         "Pause", /**/"",    "",    "",/***/
         "0x78",          "0x78",          "0x78", /**/"",    "",    "",/***/
         "0x79",          "0x79",          "0x79", /**/"",    "",    "",/***/
         "0x7a",          "0x7a",          "0x7a", /**/"",    "",    "",/***/
         "0x7b",          "0x7b",          "0x7b", /**/"",    "",    "",/***/
         "0x7c",          "0x7c",          "0x7c", /**/"",    "",    "",/***/
      "Super_L",       "Super_L",       "Super_L", /**/"",    "",    "",/***/
      "Super_R",       "Super_R",       "Super_R", /**/"",    "",    "",/***/
         "0x7f",          "0x7f",          "0x7f", /**/"",    "",    "" /***/

==> ecore_1.2.0.orig.tar.gz: ecore-1.2.0/src/lib/ecore_fb/ecore_fb_keytable.h <==
/* this table was taken from ecore_fb, is the default en layout */
         "0x00",          "0x00",          "0x00", /**/"",    "",    "",/***/
       "Escape",        "Escape",        "Escape", /**/"",    "",    "",/***/
            "1",        "exclam",             "1", /**/"1",   "!",   "1",/***/
            "2",            "at",             "2", /**/"2",   "@",   "2",/***/
            "3",    "numbersign",             "3", /**/"3",   "#",   "3",/***/
            "4",        "dollar",             "4", /**/"4",   "$",   "4",/***/
            "5",       "percent",             "5", /**/"5",   "%",   "5",/***/
            "6",  "asciicircumm",             "6", /**/"6",   "^",   "6",/***/
            "7",     "ampersand",             "7", /**/"7",   "&",   "7",/***/
            "8",       "asterisk",            "8", /**/"8",   "*",   "8",/***/
            "9",     "parenleft",             "9", /**/"9",   "(",   "9",/***/
            "0",    "parenright",             "0", /**/"0",   ")",   "0",/***/
        "minus",    "underscore",         "minus", /**/"-",   "_",   "-",/***/
        "equal",          "plus",         "equal", /**/"=",   "+",   "=",/***/
    "BackSpace",     "BackSpace",     "BackSpace", /**/"\010","\010","\010",/***/
          "Tab",  "ISO_Left_Tab",           "Tab", /**/"\011","",    "\011",/***/
            "q",             "Q",             "Q", /**/"q",   "Q",   "Q",/***/
            "w",             "W",             "W", /**/"w",   "W",   "W",/***/
            "e",             "E",             "E", /**/"e",   "E",   "E",/***/
            "r",             "R",             "R", /**/"r",   "R",   "R",/***/
            "t",             "T",             "T", /**/"t",   "T",   "T",/***/
            "y",             "Y",             "Y", /**/"y",   "Y",   "Y",/***/
            "u",             "U",             "U", /**/"u",   "U",   "U",/***/
            "i",             "I",             "I", /**/"i",   "I",   "I",/***/
            "o",             "O",             "O", /**/"o",   "O",   "O",/***/
            "p",             "P",             "P", /**/"p",   "P",   "P",/***/
  "bracketleft",     "braceleft",   "bracketleft", /**/"[",   "{",   "[",/***/
 "bracketright",    "braceright",  "bracketright", /**/"]",   "}",   "]",/***/
       "Return",        "Return",        "Return", /**/"\015","\015","\015",/***/
    "Control_L",     "Control_L",     "Control_L", /**/"",    "",    "",/***/
            "a",             "A",             "A", /**/"a",   "A",   "A",/***/
            "s",             "S",             "S", /**/"s",   "S",   "S",/***/
            "d",             "D",             "D", /**/"d",   "D",   "D",/***/
            "f",             "F",             "F", /**/"f",   "F",   "F",/***/
            "g",             "G",             "G", /**/"g",   "G",   "G",/***/
            "h",             "h",             "H", /**/"h",   "H",   "H",/***/
            "j",             "J",             "J", /**/"j",   "J",   "J",/***/
            "k",             "K",             "K", /**/"k",   "K",   "K",/***/
            "l",             "L",             "L", /**/"l",   "L",   "L",/***/
    "semicolon",         "colon",     "semicolon", /**/";",   ":",   ";",/***/
   "apostrophe",      "quotedbl",    "apostrophe", /**/"'",   "\"",  "'",/***/
        "grave",    "asciitilde",         "grave", /**/"`",   "~",   "`",/***/
      "Shift_L",       "Shift_L",       "Shift_L", /**/"",    "",    "",/***/
    "backslash",           "bar",     "backslash", /**/"\\",  "|",   "\\",/***/
            "z",             "Z",             "Z", /**/"z",   "Z",   "Z",/***/
            "x",             "X",             "X", /**/"x",   "X",   "X",/***/
            "c",             "C",             "C", /**/"c",   "C",   "C",/***/
            "v",             "V",             "V", /**/"v",   "V",   "V",/***/
            "b",             "B",             "B", /**/"b",   "B",   "B",/***/
            "n",             "N",             "N", /**/"n",   "N",   "N",/***/
            "m",             "M",             "M", /**/"m",   "M",   "M",/***/
        "comma",          "less",         "comma", /**/",",   "<",   ",",/***/
       "period",       "greater",        "period", /**/".",   ">",   ".",/***/
        "slash",      "question",         "slash", /**/"/",   "?",   "/",/***/
      "Shift_R",       "Shift_R",       "Shift_R", /**/"",    "",    "",/***/
  "KP_Multiply",   "KP_Multiply",   "KP_Multiply", /**/"",    "*",   "",/***/
        "Alt_L",         "Alt_L",         "Alt_L", /**/"",    "",    "",/***/
        "space",         "space",         "space", /**/" ",   " ",   " ",/***/
    "Caps_Lock",     "Caps_Lock",     "Caps_Lock", /**/"",    "",    "",/***/
           "F1",            "F1",            "F1", /**/"",    "",    "",/***/
           "F2",            "F2",            "F2", /**/"",    "",    "",/***/
           "F3",            "F3",            "F3", /**/"",    "",    "",/***/
           "F4",            "F4",            "F4", /**/"",    "",    "",/***/
           "F5",            "F5",            "F5", /**/"",    "",    "",/***/
           "F6",            "F6",            "F6", /**/"",    "",    "",/***/
           "F7",            "F7",            "F7", /**/"",    "",    "",/***/
           "F8",            "F8",            "F8", /**/"",    "",    "",/***/
           "F9",            "F9",            "F9", /**/"",    "",    "",/***/
          "F10",           "F10",           "F10", /**/"",    "",    "",/***/
     "Num_Lock",      "Num_Lock",      "Num_Lock", /**/"",    "",    "",/***/
  "Scroll_Lock",   "Scroll_Lock",   "Scroll_Lock", /**/"",    "",    "",/***/
      "KP_Home",          "KP_7",       "KP_Home", /**/"",    "7",   "",/***/
        "KP_Up",          "KP_8",         "KP_Up", /**/"",    "8",   "",/***/
     "KP_Prior",          "KP_9",      "KP_Prior", /**/"",    "9",   "",/***/
  "KP_Subtract",   "KP_Subtract",   "KP_Subtract", /**/"",    "",    "",/***/
      "KP_Left",          "KP_4",       "KP_Left", /**/"",    "4",   "",/***/
     "KP_Begin",          "KP_5",      "KP_Begin", /**/"",    "5",   "",/***/
     "KP_Right",          "KP_6",      "KP_Right", /**/"",    "6",   "",/***/
       "KP_Add",        "KP_Add",        "KP_Add", /**/"",    "",    "",/***/
       "KP_End",          "KP_1",        "KP_End", /**/"",    "1",   "",/***/
      "KP_Down",          "KP_2",       "KP_Down", /**/"",    "2",   "",/***/
      "KP_Next",          "KP_3",       "KP_Next", /**/"",    "3",   "",/***/
    "KP_Insert",          "KP_0",     "KP_Insert", /**/"",    "0",   "",/***/
    "KP_Delete",    "KP_Decimal",     "KP_Delete", /**/"",    ".",   "",/***/
         "0x54",          "0x54",          "0x54", /**/"",    "",    "",/***/
         "0x55",          "0x55",          "0x55", /**/"",    "",    "",/***/
         "0x56",          "0x56",          "0x56", /**/"",    "",    "",/***/
          "F11",           "F11",           "F11", /**/"",    "",    "",/***/
          "F12",           "F12",           "F12", /**/"",    "",    "",/***/
         "0x59",          "0x59",          "0x59", /**/"",    "",    "",/***/
         "0x5a",          "0x5a",          "0x5a", /**/"",    "",    "",/***/
         "0x5b",          "0x5b",          "0x5b", /**/"",    "",    "",/***/
         "0x5c",          "0x5c",          "0x5c", /**/"",    "",    "",/***/
         "0x5d",          "0x5d",          "0x5d", /**/"",    "",    "",/***/
         "0x5e",          "0x5e",          "0x5e", /**/"",    "",    "",/***/
         "0x5f",          "0x5f",          "0x5f", /**/"",    "",    "",/***/
     "KP_Enter",      "KP_Enter",      "KP_Enter", /**/"",    "",    "",/***/
    "Control_R",     "Control_R",     "Control_R", /**/"",    "",    "",/***/
    "KP_Divide",     "KP_Divide",     "KP_Divide", /**/"",    "",    "",/***/
        "Print",         "Print",         "Print", /**/"",    "",    "",/***/
        "Alt_R",         "Alt_R",         "Alt_R", /**/"",    "",    "",/***/
         "0x65",          "0x65",          "0x65", /**/"",    "",    "",/***/
         "Home",          "Home",          "Home", /**/"",    "",    "",/***/
           "Up",            "Up",            "Up", /**/"",    "",    "",/***/
        "Prior",         "Prior",         "Prior", /**/"",    "",    "",/***/
         "Left",          "Left",          "Left", /**/"",    "",    "",/***/
        "Right",         "Right",         "Right", /**/"",    "",    "",/***/
          "End",           "End",           "End", /**/"",    "",    "",/***/
         "Down",          "Down",          "Down", /**/"",    "",    "",/***/
         "Next",          "Next",          "Next", /**/"",    "",    "",/***/
       "Insert",        "Insert",        "Insert", /**/"",    "",    "",/***/
       "Delete",        "Delete",        "Delete", /**/"\177","\177","\177",/***/
         "0x70",          "0x70",          "0x70", /**/"",    "",    "",/***/
         "0x71",          "0x71",          "0x71", /**/"",    "",    "",/***/
         "0x72",          "0x72",          "0x72", /**/"",    "",    "",/***/
         "0x73",          "0x73",          "0x73", /**/"",    "",    "",/***/
         "0x74",          "0x74",          "0x74", /**/"",    "",    "",/***/
         "0x75",          "0x75",          "0x75", /**/"",    "",    "",/***/
         "0x76",          "0x76",          "0x76", /**/"",    "",    "",/***/
        "Pause",         "Pause",         "Pause", /**/"",    "",    "",/***/
         "0x78",          "0x78",          "0x78", /**/"",    "",    "",/***/
         "0x79",          "0x79",          "0x79", /**/"",    "",    "",/***/
         "0x7a",          "0x7a",          "0x7a", /**/"",    "",    "",/***/
         "0x7b",          "0x7b",          "0x7b", /**/"",    "",    "",/***/
         "0x7c",          "0x7c",          "0x7c", /**/"",    "",    "",/***/
      "Super_L",       "Super_L",       "Super_L", /**/"",    "",    "",/***/
      "Super_R",       "Super_R",       "Super_R", /**/"",    "",    "",/***/
         "0x7f",          "0x7f",          "0x7f", /**/"",    "",    "" /***/
